=======
Credits
=======

Development Lead
----------------

* UNCOVER TRUTH Inc. <develop@uncovertruth.co.jp>

Contributors
------------

* None yet. Why not be the first?
* `We are hiring`_

.. _`We are hiring`: https://www.wantedly.com/companies/uncovertruth/
